@@ -1,21 +1,8 @@
-/******************************************************************************
-*   Copyright 2011 by Aaron Seigo <aseigo@kde.org>                            *
-*                                                                             *
-*   This library is free software; you can redistribute it and/or             *
-*   modify it under the terms of the GNU Library General Public               *
-*   License as published by the Free Software Foundation; either              *
-*   version 2 of the License, or (at your option) any later version.          *
-*                                                                             *
-*   This library is distributed in the hope that it will be useful,           *
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
-*   Library General Public License for more details.                          *
-*                                                                             *
-*   You should have received a copy of the GNU Library General Public License *
-*   along with this library; see the file COPYING.LIB.  If not, write to      *
-*   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
-*   Boston, MA 02110-1301, USA.                                               *
-*******************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2011 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KPACKAGE_PACKAGESTRUCTURE_H
 #define KPACKAGE_PACKAGESTRUCTURE_H
@@ -24,13 +11,11 @@
 
 #include <KPluginFactory>
 
-#include <kpackage/package_export.h>
 #include <kpackage/package.h>
-#include <kpackage/version.h>
+#include <kpackage/package_export.h>
 
 namespace KPackage
 {
-
 class PackageStructurePrivate;
 
 /**
@@ -58,10 +43,9 @@ class KPACKAGE_EXPORT PackageStructure : public QObject
     Q_OBJECT
 
 public:
-
     explicit PackageStructure(QObject *parent = nullptr, const QVariantList &args = QVariantList());
 
-    ~PackageStructure();
+    ~PackageStructure() override;
 
     /**
      * Called when a the PackageStructure should initialize a Package with the initial
@@ -132,8 +116,6 @@ private:
  * Register a Package class when it is contained in a loadable module
  */
 
-#define K_EXPORT_KPACKAGE_PACKAGE_WITH_JSON(classname, jsonFile) \
-    K_PLUGIN_FACTORY_WITH_JSON(factory, jsonFile, registerPlugin<classname>();) \
-    K_EXPORT_PLUGIN_VERSION(PACKAGE_VERSION)
+#define K_EXPORT_KPACKAGE_PACKAGE_WITH_JSON(classname, jsonFile) K_PLUGIN_FACTORY_WITH_JSON(factory, jsonFile, registerPlugin<classname>();)
 
 #endif
